[![pypi](https://img.shields.io/pypi/v/lndb_schema_core?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lndb_schema_core)

# lndb-schema-core: Core schema module

This package is in private beta at this moment!

Follow https://twitter.com/laminlabs to learn about a first public release.

For beta users: Read the [docs](https://lamin.ai/docs/lndb-schema-core).
